## ----------------------------------------------------------------------------
## Bera, Sosa-Escudero and Yoon (2001)
##
## data
## availability: none
## firms: General Motors, Chrysler, General Electric, Westinghouse, US Steel
##        (taken from Greene, 4e, 2000)
## errors: as in Greene (1993/2000/2003)
##
## analysis
## result: exact at precision given (except for tiny deviation for RSO_mu*)
## ----------------------------------------------------------------------------

## preliminaries
source("start.R")

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("General Motors", "Chrysler", "General Electric",
  "Westinghouse", "US Steel"))
gr$firm <- factor(gr$firm)
gr$invest[c(66, 78)] <- c(261.6, 645.2)
gr$capital[72] <- 232.6
pgr <- plm.data(gr, c("firm", "year"))


## model fitting
fm_pool <- plm(invest ~ value + capital, data = pgr, model = "pooling")

## preliminary computations for Table 1
rr <- residuals(fm_pool)
u <- rr[-((0:4) * 20 + 1)]
u1 <- rr[-((1:5) * 20)]
A <- 1 - crossprod(rr, kronecker(diag(5), matrix(1, nrow = 20, ncol = 20)) %*% rr) / sum(rr^2)
B <- crossprod(u, u1) / sum(u^2)

## Table 1 (p. 13) gives the following statistics:
plmtest(invest ~ value + capital, data = pgr, type = "bp")     ## RS_mu
5 * 20 * (A + 2*B)^2 / 2 / (20 - 1) / (1 - 2/20)               ## RS_mu*
5 * 20^2 * B^2 / (20 - 1)                                      ## RS_rho
pbsytest(invest ~ value + capital, data = pgr)                 ## RS_rho*
pbsytest(invest ~ value + capital, data = pgr, test = "J")     ## RS_mu,rho
plmtest(invest ~ value + capital, data = pgr, type = "honda")  ## RSO_mu
pbsytest(invest ~ value + capital, data = pgr, test = "RE")    ## RSO_mu*
## small deviation for RSO_mu* = 19.60059 instead of 19.605
