## ----------------------------------------------------------------------------
## Griffiths, Hill, Judge (1993) -> Vinod and Ullah (1981) -> (Maddala (1977)) / Boot and De Wit (1960)
##
## data
## availability: printed
## firms: General Motors, US Steel, General Electric, Chrysler, Atlantic Refining,
##        IBM, Union Oil, Westinghouse, Goodyear, Diamond Match
## errors: invest_AR,1953 = 81.90 (Atlantic Refining)
##         capital_US,1946 = 232.6 (US Steel)
##         invest_US,1952 = 645.2 (US Steel)
##         call Atlantic Refining Atlantic Richfield
##
## analysis
## result: exact at precision given 
## ----------------------------------------------------------------------------

## preliminaries
source("start.R")


## Table 17.2 (firms unlabeled)

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("General Electric", "Westinghouse"))
gr$firm <- factor(gr$firm)
pgr <- plm.data(gr, c("firm", "year"))

## model fitting
sf_ols <- systemfit(invest ~ value + capital, data = pgr, method = "OLS")
sf_sur <- systemfit(invest ~ value + capital, data = pgr, method = "SUR",
  control = systemfit.control(methodResidCov = "noDfCor"))
summary(sf_ols)
summary(sf_sur)


## Table 17B.2 (firms unlabeled)

## data pre-processing
gr <- subset(Grunfeld, firm %in% c("General Motors", "US Steel", "General Electric", "Chrysler",
  "Atlantic Refining", "IBM", "Union Oil", "Westinghouse", "Goodyear", "Diamond Match"))
gr$firm <- factor(gr$firm)
gr$invest[c(19, 158)] <- c(81.90, 645.2)
gr$capital[152] <- 232.6
pgr <- plm.data(gr, c("firm", "year"))

## model fitting
lm_within <- lm(invest ~ 0 + firm + value + capital, data = gr)
summary(lm_within)

